@@ -1087,16 +1087,16 @@ static struct	_config
 
 static gchar	*font_override_1[] =
 	{
-	"-b&h-lucida-bold-r-normal-*-*-140-*-*-*-*-*-*",		/* large  */
-	"-b&h-lucida-medium-r-normal-*-*-120-*-*-*-*-*-*",		/* normal */
-	"-adobe-helvetica-medium-r-*-*-*-100-*-*-*-*-*-*"		/* small  */
+	"-b&h-lucida-bold-r-normal-*-*-140-*-*-*-*-iso8859-*",		/* large  */
+	"-b&h-lucida-medium-r-normal-*-*-120-*-*-*-*-iso8859-*",		/* normal */
+	"-adobe-helvetica-medium-r-*-*-*-100-*-*-*-*-iso8859-*"		/* small  */
 	};
 
 static gchar	*font_override_2[] =
 	{
-	"-b&h-lucida-bold-r-normal-*-*-160-*-*-*-*-*-*",		/* large  */
-	"-b&h-lucida-medium-r-normal-*-*-140-*-*-*-*-*-*",		/* normal */
-	"-adobe-helvetica-medium-r-*-*-*-120-*-*-*-*-*-*"		/* small  */
+	"-b&h-lucida-bold-r-normal-*-*-160-*-*-*-*-iso8859-*",		/* large  */
+	"-b&h-lucida-medium-r-normal-*-*-140-*-*-*-*-iso8859-*",		/* normal */
+	"-adobe-helvetica-medium-r-*-*-*-120-*-*-*-*-iso8859-*"		/* small  */
 	};
 
   /* Handle borders set in gkrellmrc which are not set by a style line.
@@ -1432,9 +1432,9 @@ static gchar	*base_theme[]	=
 
 static gchar	*default_fonts[] =
 	{
-	"-b&h-lucida-bold-r-normal-*-*-120-*-*-*-*-*-*",		/* large  */
-	"-b&h-lucida-medium-r-normal-*-*-100-*-*-*-*-*-*",		/* normal */
-	"-adobe-helvetica-medium-r-normal-*-*-80-*-*-*-*-*-*"	/* small  */
+	"-b&h-lucida-bold-r-normal-*-*-120-*-*-*-*-iso8859-*",		/* large  */
+	"-b&h-lucida-medium-r-normal-*-*-100-*-*-*-*-iso8859-*",		/* normal */
+	"-adobe-helvetica-medium-r-normal-*-*-80-*-*-*-*-iso8859-*"	/* small  */
 	};
 
 static void
