@@ -872,13 +872,10 @@ save_disk_config(FILE *f)
 
 	if (n_disks == 0)
 		return;
-	fprintf(f, "%s composite %d %d %d\n", DISK_CONFIG_KEYWORD,
-				composite_disk->enabled, composite_disk->resolution,
-				composite_disk->extra_info);
-	for (list = disk_mon_list->next; list; list = list->next)
+	for (list = disk_mon_list; list; list = list->next)
 		{
 		disk = (DiskMon *) list->data;
-		if (!using_DiskN_names)
+		if (!using_DiskN_names && disk != composite_disk)
 			fprintf(f, "%s enable (%d,%d) %d %d %d\n", DISK_CONFIG_KEYWORD,
 					disk->major, disk->minor, disk->enabled,
 					disk->resolution, disk->extra_info);
@@ -908,7 +905,7 @@ load_disk_config(gchar *arg)
 	n = sscanf(arg, "%31s %[^\n]", config, item);
 	if (n == 2)
 		{
-		if (strcmp(config, "composite") == 0)
+		if (strcmp(config, "composite") == 0)	/* XXX Obsolete >= 1.0.8 */
 			sscanf(item, "%d %d %d", &composite_disk->enabled,
 					&composite_disk->resolution, &composite_disk->extra_info);
 		else if (strcmp(config, "enable") == 0)
