@@ -477,13 +477,13 @@ GtkWidget	*track_gtk_button;
 
 static gchar	*text_fonts[2][3] =
 {
-{"-adobe-helvetica-medium-r-normal-*-*-100-*-*-*-*-*,-*-*-medium-r-*-*-10-*-*-*-*-*-*-*",
-"-adobe-helvetica-bold-r-normal-*-*-100-*-*-*-*-*-*,-*-*-bold-r-*-*-10-*-*-*-*-*-*-*,-*-*-medium-r-*-*-10-*-*-*-*-*-*-*",
-"-adobe-helvetica-bold-o-normal-*-*-100-*-*-*-*-*,-*-*-bold-o-*-*-10-*-*-*-*-*-*-*,-*-*-medium-r-*-*-10-*-*-*-*-*-*-*"},
+{"-adobe-helvetica-medium-r-normal-*-*-100-*-*-*-iso8859-*,-*-*-medium-r-*-*-10-*-*-*-*-*-iso8859-*",
+"-adobe-helvetica-bold-r-normal-*-*-100-*-*-*-*-iso8859-*,-*-*-bold-r-*-*-10-*-*-*-*-*-iso8859-*,-*-*-medium-r-*-*-10-*-*-*-*-*-iso8859-*",
+"-adobe-helvetica-bold-o-normal-*-*-100-*-*-*-iso8859-*,-*-*-bold-o-*-*-10-*-*-*-*-*-iso8859-*,-*-*-medium-r-*-*-10-*-*-*-*-*-iso8859-*"},
 
-{"-adobe-helvetica-medium-r-normal-*-*-120-*-*-*-*-*,-*-*-medium-r-*-*-12-*-*-*-*-*-*-*",
-"-adobe-helvetica-bold-r-normal-*-*-120-*-*-*-*-*-*,-*-*-bold-r-*-*-12-*-*-*-*-*-*-*,-*-*-medium-r-*-*-12-*-*-*-*-*-*-*",
-"-adobe-helvetica-bold-o-normal-*-*-120-*-*-*-*-*,-*-*-bold-o-*-*-12-*-*-*-*-*-*-*,-*-*-medium-r-*-*-12-*-*-*-*-*-*-*"}
+{"-adobe-helvetica-medium-r-normal-*-*-120-*-*-*-iso8859-*,-*-*-medium-r-*-*-12-*-*-*-*-*-iso8859-*",
+"-adobe-helvetica-bold-r-normal-*-*-120-*-*-*-*-iso8859-*,-*-*-bold-r-*-*-12-*-*-*-*-*-iso8859-*,-*-*-medium-r-*-*-12-*-*-*-*-*-iso8859-*",
+"-adobe-helvetica-bold-o-normal-*-*-120-*-*-*-iso8859-*,-*-*-bold-o-*-*-12-*-*-*-*-*-iso8859-*,-*-*-medium-r-*-*-12-*-*-*-*-*-iso8859-*"}
 };
 
 static void
