@@ -114,20 +114,20 @@ static void		apply_frame_transparency(void);
 
 static gchar	*fail_large_font[2] =
 {
-"-b&h-lucida-bold-r-normal-*-*-120-*-*-*-*-*-*",
-"-adobe-courier-medium-r-*-*-*-120-*-*-*-*-*-*"
+"-b&h-lucida-bold-r-normal-*-*-120-*-*-*-*-iso8859-*",
+"-adobe-courier-medium-r-*-*-*-120-*-*-*-*-iso8859-*"
 };
 
 static gchar	*fail_normal_font[2] =
 {
-"-b&h-lucida-medium-r-normal-*-*-100-*-*-*-*-*-*",
-"-adobe-courier-medium-r-*-*-*-100-*-*-*-*-*-*"
+"-b&h-lucida-medium-r-normal-*-*-100-*-*-*-*-iso8859-*",
+"-adobe-courier-medium-r-*-*-*-100-*-*-*-*-iso8859-*"
 };
 
 static gchar	*fail_small_font[2] =
 {
-"-adobe-helvetica-medium-r-normal-*-*-80-*-*-*-*-*-*",
-"-adobe-courier-medium-r-*-*-*-80-*-*-*-*-*-*"
+"-adobe-helvetica-medium-r-normal-*-*-80-*-*-*-*-iso8859-*",
+"-adobe-courier-medium-r-*-*-*-80-*-*-*-*-iso8859-*"
 };
 
 
