@@ -435,9 +435,14 @@ is_linux_ISDN_online()
 	char	buffer[512], *p, *end;
 	int		i;
 
-	if ((f = fopen ("/dev/isdninfo", "r")) == NULL)
+	if (   (f = fopen ("/dev/isdninfo", "r")) == NULL
+		&& (f = fopen("/dev/isdn/isdninfo", "r")) == NULL
+	   )
+		{
+		if (GK.debug_level & DEBUG_NET)
+			printf("is_linux_ISDN_online: no /dev/isdninfo?\n");
 		return FALSE;
-
+		}
 	 for (i = 0; i < 5; i++)
 		{
 		if (fgets (buffer, BUFSIZ, f) == NULL)
